@@ -151,12 +151,27 @@ class AIREventsAPI(BaseAPIClient):
         return self.client.events.create(items[0] if single_item else items)
 
     def create(self, event: Union[Event, List[Event]]) -> Union[Event, EventList]:
+        """Create an AIR-conform  Event or a list of Events.
+            The Events will be versioned but not seen through the front end (for that use the `create_alert` method).
+
+        Args:
+            event (Union[Event, List[Event]]): Event or a list of Events
+
+        Returns:
+            (nion[Event, EventList]: Created Event or EventList
+
+        """
         return self._create(event, is_alert=False)
 
     def create_alert(self, event: Union[Event, List[Event]]) -> Union[Event, EventList]:
-        """
-        Create one or more alert event(s) that by default are shown in front end.
-        Pass event(s) with metadata field 'show' set to 'False' to hide.
+        """Create one or more alert event(s) that by default are shown in front end.
+            Pass event(s) with metadata field 'show' set to 'False' to hide.
+
+        Args:
+            event (Union[Event, List[Event]]): Event or a list of Events
+
+        Returns:
+            Union[Event, EventList]: Created Event or EventList
         """
         return self._create(event, is_alert=True)
 
